@@ -1,7 +1,5 @@
-use strict;
-use warnings;
 package Sumu::Perl::Modules;
-$Sumu::Perl::Modules::VERSION = '0.001';
+
 # ABSTRACT: Perl Modules
 
 =head1 NAME
@@ -10,10 +8,59 @@ $Sumu::Perl::Modules::VERSION = '0.001';
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head2 Strictures
+    Enable strict and warnings
+=cut
+
+use strict;
+use warnings;
+
+=head2 VERSION
+=cut
+
+our $VERSION = '0.0.1';
+
+use parent qw(Exporter); 
+require Exporter; 
+our @ISA = ("Exporter"); 
+
+our @EXPORT_OK = qw(
+    _extutils 
+    _dirs 
+    _doc
+); 
+
+=head3 sub NAME
+    Returns the name of the app/module
+=cut
+
+sub NAME { my $self = shift; my $NAME = "Perl Modules"; return $NAME; }
+
+
+=head3 Sub new
+
+=cut
+
+sub new {
+	my $class = shift;
+	my $self  = bless { @_ }, $class;
+	return $self;
+}
+
+
+=head3 Required Modules, CPAN
+    ExtUtils::Installed
+=cut
 
 use ExtUtils::Installed;
 
+
+=head3 Sub _extutils
+    Returns List of modules 
+=cut
+
 sub _extutils {
 
     my $c = shift;
@@ -58,8 +105,8 @@ sub _extutils {
 # end 
 
 
-=head3 Show Dirs 
-    in a module 
+=head3 Sub _dirs 
+    Show/Get Dirs in a module 
 =cut
 
 sub _dirs  {
@@ -116,8 +163,8 @@ sub _dirs  {
 }
 # end 
 
-=head3 Show Doc 
-    for a module 
+=head3 Sub _doc
+    Show Doc for a module 
 =cut
 
 sub _doc {
